@@ -7,19 +7,19 @@ import torch
 from einops import rearrange, repeat
 from pytorch_lightning import seed_everything
 
-from api import _prompts_to_embeddings, IMAGINAIRY_SAFETY_MODE
+from classy_imaginary.api import _prompts_to_embeddings, IMAGINAIRY_SAFETY_MODE
 from classy_imaginary import ImaginePrompt, ImagineResult
-from enhancers.clip_masking import get_img_mask
-from enhancers.face_restoration_codeformer import enhance_faces
-from enhancers.upscale_realesrgan import upscale_image
-from img_utils import pillow_fit_image_within, pillow_img_to_torch_image
-from log_utils import ImageLoggingContext, log_conditioning, log_img, log_latent
-from model_manager import get_diffusion_model
-from modules.midas.utils import AddMiDaS
-from safety import create_safety_score
-from samplers import SAMPLER_LOOKUP
-from samplers.base import NoiseSchedule, noise_an_image
-from utils import get_device, platform_appropriate_autocast, fix_torch_nn_layer_norm, fix_torch_group_norm, randn_seeded
+from classy_imaginary.enhancers.clip_masking import get_img_mask
+from classy_imaginary.enhancers.face_restoration_codeformer import enhance_faces
+from classy_imaginary.enhancers.upscale_realesrgan import upscale_image
+from classy_imaginary.img_utils import pillow_fit_image_within, pillow_img_to_torch_image
+from classy_imaginary.log_utils import ImageLoggingContext, log_conditioning, log_img, log_latent
+from classy_imaginary.model_manager import get_diffusion_model
+from classy_imaginary.modules.midas.utils import AddMiDaS
+from classy_imaginary.safety import create_safety_score
+from classy_imaginary.samplers import SAMPLER_LOOKUP
+from classy_imaginary.samplers.base import NoiseSchedule, noise_an_image
+from classy_imaginary.utils import get_device, platform_appropriate_autocast, fix_torch_nn_layer_norm, fix_torch_group_norm, randn_seeded
 import logging
 
 logger = logging.getLogger(__name__)
